@@ -1,17 +1,16 @@
-/* vim:set shiftwidth=4 ts=8: */
-
+/// @file
+/// @ingroup public_apis
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef GV_COLOR_H
-#define GV_COLOR_H
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
@@ -24,7 +23,7 @@ typedef struct hsvrgbacolor_t {
 } hsvrgbacolor_t;
 
 /* possible representations of color in gvcolor_t */
-typedef enum { HSVA_DOUBLE, RGBA_BYTE, RGBA_WORD, CMYK_BYTE,
+typedef enum { HSVA_DOUBLE, RGBA_BYTE, RGBA_WORD,
 		RGBA_DOUBLE, COLOR_STRING, COLOR_INDEX } color_type_t;
 
 /* gvcolor_t can hold a color spec in a choice or representations */
@@ -33,7 +32,6 @@ typedef struct color_s {
 	double RGBA[4];
 	double HSVA[4];
 	unsigned char rgba[4];
-	unsigned char cmyk[4];
 	int rrggbbaa[4];
 	char *string;
 	int index;
@@ -48,4 +46,3 @@ typedef struct color_s {
 #ifdef __cplusplus
 }
 #endif
-#endif
