@@ -1,17 +1,16 @@
-/* vim:set shiftwidth=4 ts=8: */
-
+/// @file
+/// @ingroup plugin_api
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef GVDEVICE_PLUGIN_H
-#define GVDEVICE_PLUGIN_H
+#pragma once
 
 #include "types.h"
 #include "gvplugin.h"
@@ -21,6 +20,7 @@
 extern "C" {
 #endif
 
+    /// @ingroup plugin_api
     struct gvdevice_engine_s {
 	void (*initialize) (GVJ_t * firstjob);
 	void (*format) (GVJ_t * firstjob);
@@ -30,4 +30,3 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-#endif				/* GVDEVICE_PLUGIN_H */
